@@ -196,6 +196,9 @@ type Context interface {
 
 	// LastOpenedBlock returns a last node that is currently in parsing.
 	LastOpenedBlock() Block
+
+	// IsInLinkLabel returns true if current position seems to be in link label.
+	IsInLinkLabel() bool
 }
 
 // A ContextConfig struct is a data structure that holds configuration of the Context.
@@ -206,6 +209,7 @@ type ContextConfig struct {
 // An ContextOption is a functional option type for the Context.
 type ContextOption func(*ContextConfig)
 
+// WithIDs is a functional option for the Context.
 func WithIDs(ids IDs) ContextOption {
 	return func(c *ContextConfig) {
 		c.IDs = ids
@@ -377,6 +381,11 @@ func (p *parseContext) LastOpenedBlock() Block {
 	return Block{}
 }
 
+func (p *parseContext) IsInLinkLabel() bool {
+	tlist := p.Get(linkLabelStateKey)
+	return tlist != nil
+}
+
 // State represents parser's state.
 // State is designed to use as a bit flag.
 type State int
@@ -450,7 +459,7 @@ type Parser interface {
 	// Parse parses the given Markdown text into AST nodes.
 	Parse(reader text.Reader, opts ...ParseOption) ast.Node
 
-	// AddOption adds the given option to thie parser.
+	// AddOption adds the given option to this parser.
 	AddOptions(...Option)
 }
 
@@ -496,7 +505,7 @@ type BlockParser interface {
 	// Close will be called when the parser returns Close.
 	Close(node ast.Node, reader text.Reader, pc Context)
 
-	// CanInterruptParagraph returns true if the parser can interrupt pargraphs,
+	// CanInterruptParagraph returns true if the parser can interrupt paragraphs,
 	// otherwise false.
 	CanInterruptParagraph() bool
 
@@ -990,8 +999,9 @@ type lineStat struct {
 }
 
 func isBlankLine(lineNum, level int, stats []lineStat) bool {
-	ret := false
+	ret := true
 	for i := len(stats) - 1 - level; i >= 0; i-- {
+		ret = false
 		s := stats[i]
 		if s.lineNum == lineNum {
 			if s.level < level && s.isBlank {
